@@ -58,3 +58,8 @@ const regexp_engine pcre2_engine = {
     PCRE2_op_comp,
 #endif
 };
+
+struct re_engine_pcre2_data {
+    pcre2_code *ri;
+    pcre2_match_data *match_data;
+};
